@@ -21,45 +21,23 @@ from pydantic import BaseModel
 class Activity(BaseModel):
     """ETOS activity events."""
 
-    triggered: Optional[dict]
-    canceled: Optional[dict]
-    finished: Optional[dict]
-
-
-class Environment(BaseModel):
-    """ETOS environment events."""
-
-    name: str
-    uri: Optional[str]
-
-
-class Announcement(BaseModel):
-    """ETOS announcements."""
-
-    heading: str
-    body: str
-
-
-class Artifact(BaseModel):
-    """ETOS artifact."""
-
-    files: list[str]
-    suite_name: str
-    location: str
+    triggered: Optional[dict] = None
+    canceled: Optional[dict] = None
+    finished: Optional[dict] = None
 
 
 class SubSuite(BaseModel):
     """ETOS sub suite events."""
 
-    started: Optional[dict]
-    finished: Optional[dict]
+    started: Optional[dict] = None
+    finished: Optional[dict] = None
 
 
 class TestSuite(BaseModel):
     """ETOS main suite events."""
 
-    started: Optional[dict]
-    finished: Optional[dict]
+    started: Optional[dict] = None
+    finished: Optional[dict] = None
     sub_suites: list[SubSuite] = []
 
 
@@ -67,8 +45,5 @@ class Events(BaseModel):
     """ETOS events."""
 
     activity: Activity = Activity()
-    tercc: Optional[dict]
+    tercc: Optional[dict] = None
     main_suites: list[TestSuite] = []
-    environments: list[Environment] = []
-    announcements: list[Announcement] = []
-    artifacts: list[Artifact] = []
